@@ -45,6 +45,7 @@
 #include "util.h"
 #include "gsm-sound.h"
 #include "gsm-gsd.h"
+#include "gsm-proxy.h"
 #include "gsm-keyring.h"
 #include "gsm-xrandr.h"
 #include "gsm-at-startup.h"
@@ -397,7 +398,10 @@ main (int argc, char *argv[])
   a_t_support = gconf_client_get_bool (gconf_client, ACCESSIBILITY_KEY, NULL);
 
   if (a_t_support)
-    gsm_at_set_gtk_modules ();
+    {
+      gsm_assistive_registry_start ();
+      gsm_at_set_gtk_modules ();
+    }
 
   goption_context = g_option_context_new (_("- Manage the GNOME session"));
   g_option_context_add_main_entries (goption_context, options, GETTEXT_PACKAGE);
@@ -429,6 +433,8 @@ main (int argc, char *argv[])
 
   ignore (SIGPIPE);
 
+  gsm_set_up_legacy_proxy_environment ();
+
   /* Need DISPLAY set */
   gsm_keyring_daemon_start ();
   gsm_gsd_start ();
